==> requorm.js-0.0.1.tgz: package/README.md <==
requorm.js
==========

JavaScript library for checking and validating HTML forms. If any of the fields in the form incorrectly filled, submit buttons will be disabled.

#### Usage
First of all, include `requorm.js` (or minified `requorm.min.js`) to your HTML file:
```html
<head>
    <meta charset="UTF-8">
    ...
    <link rel="stylesheet" type="text/css" href="requorm.css">
    <script src="requorm.js"></script>
</head>
```
Create any form with some class name:
```html
<form class="myform">
        <input type="text" placeholder="Name">
        <input type="text" placeholder="Email">
        <input type="submit" class="button" value="Submit">
</form>
```
Init library, init default checkers and(or) add own checkers and apply to our form with class name "myform":
```html
<script>
    var r = new requorm()
    r.initDefCheckers()
    r.apply(".myform")
</script>
```

#### Addition checkers to DOM element
Library use attribure `checkers` for following tags:
* `input`
* `textarea`
* `select`

For example:
```html
<input type="text" checkers="notEmpty">
```
If the attribute is not specified, element will be ignored. One element can have multiple checkers:
```html
<input type="text" checkers="notEmpty; email()">
```
Checkers in attribute are separated by semicolon. If checker recieve any const arguments, you can point them like this:
```html
<input type="text" checkers="minlenght(8); maxlength(32);">
<input type="text" checkers="lenght(8, 32)">
<input type="text" checkers="equal(abacaba)">
```
Note, that list of arguments `10, 1.0f, true, abc abc` will be parsed as array of strings: `["10", "1.0f", "true", "abc abc"]`

#### Default checkers
- **notEmpty** - check, that field has any input
- **minLength(min)** - check, that field input has length greater or equal to `min`
- **maxLength(max)** - check, that field input has length less or equal to `max`
- **equal(input)** - check, that field input is equal to `input`
- **alpha** - check, that field input has only alphabetic characters
- **numeric** - check, that field input has only numeric characters
- **email** - check, that field input has valid e-mail form

#### Addition own checkers
For creating new checker, call `requorm.addChecker(name, func)`, where `name` is name of checker and `func` is function, that take DOM element and array of arguments and return `true|false`. Following code create new checker with name `equal`:
```javascript
var r = new requorm()
r.addChecker("equal", function(element, args) {
  return (args.length > 0) && (element.value == args[0])
})
```
After it you can use checker in html:
```html
<input type="text" checkers="equal(abacaba)">
```

#### Using CSS
If you want to mark invalid and valid fields, create in your CSS file following selectors:
* `.invalid-input`
* `.valid-input`

#### TODO
* More checkers
* Unit tests
* Documentation
* Pretty argument parser

==> requorm.js-0.0.2.tgz: package/README.md <==
requorm.js
==========

JavaScript library for checking and validating HTML forms. If any of the fields in the form incorrectly filled, submit buttons will be disabled.

#### Content
* [Examples](#examples)
* [Installation](#install)
* [Usage](#usage)
* [Addition checkers to DOM element](#addition-checkers-to-dom-element)
* [Default checkers](#default-checkers)
* [Addition own checkers](#addition-own-checkers)
* [Using CSS](#using-css)
* [Contribution](#contribution)

#### Examples
Watch examples [here](http://asaskevich.github.io/requorm.js)

#### Installation
You can download library directly from GitHub. Alternatively, you can use **npm** or **bower**:
```shell
$ npm install requorm.js
$ bower install requorm.js
```

#### Usage
First of all, include `requorm.js` (or minified `requorm.min.js`) to your HTML file:
```html
<head>
    <meta charset="UTF-8">
    ...
    <link rel="stylesheet" type="text/css" href="requorm.css">
    <script src="requorm.js"></script>
</head>
```
Create any form with some class name:
```html
<form class="myform">
        <input type="text" placeholder="Name">
        <input type="text" placeholder="Email">
        <input type="submit" class="button" value="Submit">
</form>
```
Init library, init default checkers and(or) add own checkers and apply to our form with class name "myform":
```html
<script>
    var r = new requorm()
    r.initDefCheckers()
    r.apply(".myform")
</script>
```

#### Addition checkers to DOM element
Library use attribure `checkers` for following tags:
* `input`
* `textarea`
* `select`

For example:
```html
<input type="text" checkers="notEmpty">
```
If the attribute is not specified, element will be ignored. One element can have multiple checkers:
```html
<input type="text" checkers="notEmpty; email()">
```
Checkers in attribute are separated by semicolon. If checker recieve any const arguments, you can point them like this:
```html
<input type="text" checkers="minLength(8); maxLength(32);">
<input type="text" checkers="length(8, 32)">
<input type="text" checkers="equal(abacaba)">
```
Note, that list of arguments `10, 1.0f, true, abc abc` will be parsed as array of strings: `["10", "1.0f", "true", "abc abc"]`

#### Default checkers
- **notEmpty** - check, that field has any input
- **minLength(min)** - check, that field input has length greater or equal to `min`
- **maxLength(max)** - check, that field input has length less or equal to `max`
- **equal(input)** - check, that field input is equal to `input`
- **alpha** - check, that field input has only alphabetic characters
- **numeric** - check, that field input has only numeric characters
- **email** - check, that field input has valid e-mail form

#### Addition own checkers
For creating new checker, call `requorm.addChecker(name, func)`, where `name` is name of checker and `func` is function, that take DOM element and array of arguments and return `true|false`. Following code create new checker with name `equal`:
```javascript
var r = new requorm()
r.addChecker("equal", function(element, args) {
  return (args.length > 0) && (element.value == args[0])
})
```
After it you can use checker in html:
```html
<input type="text" checkers="equal(abacaba)">
```

#### Using CSS
If you want to mark invalid and valid fields visually, use in your CSS file following selectors:
* `.invalid-input`
* `.valid-input`
* `.button[disabled]`
* `.button`

#### TODO
* More checkers
* Unit tests
* Documentation
* Pretty argument parser
* Tooltips
* Your ideas?

#### Contribution
If you do have a contribution for the package feel free to put up a Pull Request or open Issue.
